# GeomEffiBEM


[![pypi](https://img.shields.io/pypi/v/geomeffibem.svg)](https://pypi.org/project/geomeffibem/)
[![python](https://img.shields.io/pypi/pyversions/geomeffibem.svg)](https://pypi.org/project/geomeffibem/)
[![Build Status](https://github.com/jmarrec/geomeffibem/actions/workflows/dev.yml/badge.svg)](https://github.com/jmarrec/geomeffibem/actions/workflows/dev.yml)
[![codecov](https://codecov.io/gh/jmarrec/geomeffibem/branch/main/graphs/badge.svg)](https://codecov.io/github/jmarrec/geomeffibem)


A small library to facilitate some building energy modeling geometry operations with [OpenStudio](https://github.com/NREL/OpenStudio) and [EnergyPlus](https://github.com/NREL/EnergyPlus) in mind. This started as a test bed while I was implementing source code changes to both aforementioned projects and I realized this had value in creating geometry in an efficient manner as well as being able to visualize simple geometry in 2D via matplotlib.

A Jupyter Notebook [GeomEffiBEM_Demonstration.ipynb](GeomEffiBEM_Demonstration.ipynb) can serve as a small demonstration of the features.


* Documentation: <https://jmarrec.github.io/geomeffibem>
* GitHub: <https://github.com/jmarrec/geomeffibem>
* PyPI: <https://pypi.org/project/geomeffibem/>


This is free software (MIT License) contributed by [EffiBEM](https://www.effibem.com).

Leveraging software, [EffiBEM](https://www.effibem.com) specializes in providing new ways to streamline your workflows and create new tools that work with limited inputs for your specific applications. We also offer support and training services on BEM simulation engines (OpenStudio and EnergyPlus).
